vfbLib.typing.GlyphData
=======================

.. currentmodule:: vfbLib.typing

.. autoclass:: GlyphData
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphData.__init__
      ~GlyphData.clear
      ~GlyphData.copy
      ~GlyphData.fromkeys
      ~GlyphData.get
      ~GlyphData.items
      ~GlyphData.keys
      ~GlyphData.pop
      ~GlyphData.popitem
      ~GlyphData.setdefault
      ~GlyphData.update
      ~GlyphData.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphData.components
      ~GlyphData.guides
      ~GlyphData.hints
      ~GlyphData.imported
      ~GlyphData.kerning
      ~GlyphData.metrics
      ~GlyphData.name
      ~GlyphData.nodes
      ~GlyphData.num_masters
      ~GlyphData.tth
   
   